@@ -1,6 +1,6 @@
 """Entry point for python cli."""
 
-from .main import main
+from .main import cli
 
 if __name__ == '__main__':
-    main()
+    cli()
